#
# Copyright (c) 2003 Panoptic Computer Network.
#
# See the file "tcllian.license.terms" for information on usage and
# redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

#
# init.tcl --
#
#   This script gets sourced when Tcllian is started.
#
# $Id: init.tcl,v 1.7 2005/01/04 16:17:25 dossy Exp $
#

package provide Tcllian [tcllian patchlevel]

# Create a namespace to store globals in.
namespace eval ::tcllian {}

proc ::tcllian::startup {} {
    variable section_id -1
    variable group_id -1

    # Create (or get the ID to) the "web" section.  This is the
    # same section that the RSS/news, Stocks and Weather plugins
    # use.
    set section_id [trillian listAddEntry \
        section 1 previous_id -2 real_name "web" text "My Web"]

    # Create a group for Tcllian's entries.
    set group_id [trillian listAddEntry \
        group 1 section_id $section_id previous_id -2 expanded 1 \
        real_name "Tcllian" text "Tcllian"]

    # Register the /tcl alias.
    variable alias_id [trillian editAliasRegister \
        /tcl ::tcllian::aliasCallback]

    ::tkconLoader::start
}

proc ::tcllian::shutdown {} {
    variable section_id
    variable group_id
    variable alias_id

    ::tkconLoader::stop

    # Unregister the /tcl alias.
    trillian editAliasUnregister $alias_id

    # Remove our group.
    trillian listRemoveEntry $group_id
    set group_id -1

    # Remove the section, if it's empty.
    if {[trillian listGetSectionCount $section_id] == 0} {
        trillian listRemoveEntry $section_id
        set section_id -1
    }
}

proc ::tcllian::aliasCallback {event args} {
    array set opts $args
    regsub "^$opts(alias)\\s*" $opts(text) {} text
    return [eval $text]
}

proc ::tcllian::load {script} {
    uplevel #0 [list source [file join [tcllian trillian_directory] \
        plugins tcllian scripts $script]]
}

::tcllian::load tkcon-loader.tcl
::tcllian::load webstatus.tcl
::tcllian::load rss.tcl
