#
# source [file join [tcllian trillian_directory] plugins tcllian scripts webstatus.tcl]
# ::webstatus::start
#

namespace eval ::webstatus {
    proc start {} {
        variable url http://panoptic.com/trillian/update.php
        variable unique_id -1
        variable after {}

        # Every 2 minutes, send a refresh update even if our status hasn't
        # changed, otherwise we show up as "offline" by timeout.
        variable refreshrate [expr {2 * 60 * 1000}]

        # Register the event callback to send our status when it
        # changes.
        set unique_id [trillian eventsConnect "Connection: Change" {
            ::webstatus::sendUpdate $event(name) $event(medium) $event(status)
        }]

        # Register the scheduled refresh as well.
        set after [after $refreshrate {::webstatus::refresh}]
    }

    proc stop {} {
        variable unique_id
        variable after

        after cancel $after
        set after {}

        trillian eventsDisconnect $unique_id
    }

    proc sendUpdate {name medium status} {
        variable url

        regexp {^(.*)/(.*)$} $name -> name resource
        trillian httpFileRequest $url?[join [list \
                name=$name medium=$medium status=$status] &]
    }

    proc refresh {{&event {}}} {
        variable after
        variable refreshrate

        foreach connection [trillian connectionEnumerate all] {
            foreach {medium connection_id name status section} $connection {
                sendUpdate $name $medium $status
            }
        }

        # Only re-schedule refresh if previous refresh is
        # gone.  This lets us manually execute [refresh]
        # without having lots of them automatically scheduled.
        if {[lsearch [after info] $after] < 0} {
            set after [after $refreshrate {::webstatus::refresh}]
        }
    }
}

